<?php

namespace EnumType;

/**
 * This class stands for CabinType EnumType
 * Meta information extracted from the WSDL
 * - documentation: Specifies the cabin type (e.g. first, business, economy).
 * @subpackage Enumerations
 */
class CabinType
{
    /**
     * Constant for value 'First'
     * Meta information extracted from the WSDL
     * - documentation: First class compartment.
     * @return string 'First'
     */
    const VALUE_FIRST = 'First';
    /**
     * Constant for value 'Business'
     * Meta information extracted from the WSDL
     * - documentation: Business class compartment.
     * @return string 'Business'
     */
    const VALUE_BUSINESS = 'Business';
    /**
     * Constant for value 'Economy'
     * Meta information extracted from the WSDL
     * - documentation: Economy (or sometimes referred to as Coach) class compartment.
     * @return string 'Economy'
     */
    const VALUE_ECONOMY = 'Economy';
    /**
     * Return true if value is allowed
     * @uses self::getValidValues()
     * @param mixed $value value
     * @return bool true|false
     */
    public static function valueIsValid($value)
    {
        return ($value === null) || in_array($value, self::getValidValues(), true);
    }
    /**
     * Return allowed values
     * @uses self::VALUE_FIRST
     * @uses self::VALUE_BUSINESS
     * @uses self::VALUE_ECONOMY
     * @return string[]
     */
    public static function getValidValues()
    {
        return array(
            self::VALUE_FIRST,
            self::VALUE_BUSINESS,
            self::VALUE_ECONOMY,
        );
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
