<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for Access StructType
 * Meta information extracted from the WSDL
 * - documentation: The identifier of the system that performed the action on the profile record. | Describes the action taken on the record.
 * @subpackage Structs
 */
class Access extends AbstractStructBase
{
    /**
     * The AccessPerson
     * Meta information extracted from the WSDL
     * - documentation: Name of individual who originated or updated record.
     * - minOccurs: 0
     * @var \StructType\PersonNameType
     */
    public $AccessPerson;
    /**
     * The AccessComment
     * Meta information extracted from the WSDL
     * - documentation: Free text comment added by the person accessing the profile record.
     * - minOccurs: 0
     * @var \StructType\FreeTextType
     */
    public $AccessComment;
    /**
     * The ActionType
     * @var string
     */
    public $ActionType;
    /**
     * The ActionDateTime
     * Meta information extracted from the WSDL
     * - documentation: Month, day, year and optionally in hour, minute, second of day in ISO 8601 format of the action taken on the profile.
     * @var string
     */
    public $ActionDateTime;
    /**
     * The ID
     * Meta information extracted from the WSDL
     * - documentation: Used for Character Strings, length 1 to 32.
     * - base: xs:string
     * - maxLength: 32
     * - minLength: 1
     * @var string
     */
    public $ID;
    /**
     * Constructor method for Access
     * @uses Access::setAccessPerson()
     * @uses Access::setAccessComment()
     * @uses Access::setActionType()
     * @uses Access::setActionDateTime()
     * @uses Access::setID()
     * @param \StructType\PersonNameType $accessPerson
     * @param \StructType\FreeTextType $accessComment
     * @param string $actionType
     * @param string $actionDateTime
     * @param string $iD
     */
    public function __construct(\StructType\PersonNameType $accessPerson = null, \StructType\FreeTextType $accessComment = null, $actionType = null, $actionDateTime = null, $iD = null)
    {
        $this
            ->setAccessPerson($accessPerson)
            ->setAccessComment($accessComment)
            ->setActionType($actionType)
            ->setActionDateTime($actionDateTime)
            ->setID($iD);
    }
    /**
     * Get AccessPerson value
     * @return \StructType\PersonNameType|null
     */
    public function getAccessPerson()
    {
        return $this->AccessPerson;
    }
    /**
     * Set AccessPerson value
     * @param \StructType\PersonNameType $accessPerson
     * @return \StructType\Access
     */
    public function setAccessPerson(\StructType\PersonNameType $accessPerson = null)
    {
        $this->AccessPerson = $accessPerson;
        return $this;
    }
    /**
     * Get AccessComment value
     * @return \StructType\FreeTextType|null
     */
    public function getAccessComment()
    {
        return $this->AccessComment;
    }
    /**
     * Set AccessComment value
     * @param \StructType\FreeTextType $accessComment
     * @return \StructType\Access
     */
    public function setAccessComment(\StructType\FreeTextType $accessComment = null)
    {
        $this->AccessComment = $accessComment;
        return $this;
    }
    /**
     * Get ActionType value
     * @return string|null
     */
    public function getActionType()
    {
        return $this->ActionType;
    }
    /**
     * Set ActionType value
     * @param string $actionType
     * @return \StructType\Access
     */
    public function setActionType($actionType = null)
    {
        // validation for constraint: string
        if (!is_null($actionType) && !is_string($actionType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($actionType, true), gettype($actionType)), __LINE__);
        }
        $this->ActionType = $actionType;
        return $this;
    }
    /**
     * Get ActionDateTime value
     * @return string|null
     */
    public function getActionDateTime()
    {
        return $this->ActionDateTime;
    }
    /**
     * Set ActionDateTime value
     * @param string $actionDateTime
     * @return \StructType\Access
     */
    public function setActionDateTime($actionDateTime = null)
    {
        // validation for constraint: string
        if (!is_null($actionDateTime) && !is_string($actionDateTime)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($actionDateTime, true), gettype($actionDateTime)), __LINE__);
        }
        $this->ActionDateTime = $actionDateTime;
        return $this;
    }
    /**
     * Get ID value
     * @return string|null
     */
    public function getID()
    {
        return $this->ID;
    }
    /**
     * Set ID value
     * @param string $iD
     * @return \StructType\Access
     */
    public function setID($iD = null)
    {
        // validation for constraint: string
        if (!is_null($iD) && !is_string($iD)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($iD, true), gettype($iD)), __LINE__);
        }
        // validation for constraint: maxLength(32)
        if (!is_null($iD) && mb_strlen($iD) > 32) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 32', mb_strlen($iD)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($iD) && mb_strlen($iD) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($iD)), __LINE__);
        }
        $this->ID = $iD;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\Access
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
