<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for Award StructType
 * Meta information extracted from the WSDL
 * - documentation: An element that identifies the hotel ratings.
 * @subpackage Structs
 */
class Award extends AbstractStructBase
{
    /**
     * The Provider
     * Meta information extracted from the WSDL
     * - documentation: The name of the award or ratings provider.
     * - use: optional
     * @var string
     */
    public $Provider;
    /**
     * The Rating
     * Meta information extracted from the WSDL
     * - documentation: The actual award or rating received by the hotel facility.
     * - use: optional
     * @var string
     */
    public $Rating;
    /**
     * Constructor method for Award
     * @uses Award::setProvider()
     * @uses Award::setRating()
     * @param string $provider
     * @param string $rating
     */
    public function __construct($provider = null, $rating = null)
    {
        $this
            ->setProvider($provider)
            ->setRating($rating);
    }
    /**
     * Get Provider value
     * @return string|null
     */
    public function getProvider()
    {
        return $this->Provider;
    }
    /**
     * Set Provider value
     * @param string $provider
     * @return \StructType\Award
     */
    public function setProvider($provider = null)
    {
        // validation for constraint: string
        if (!is_null($provider) && !is_string($provider)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($provider, true), gettype($provider)), __LINE__);
        }
        $this->Provider = $provider;
        return $this;
    }
    /**
     * Get Rating value
     * @return string|null
     */
    public function getRating()
    {
        return $this->Rating;
    }
    /**
     * Set Rating value
     * @param string $rating
     * @return \StructType\Award
     */
    public function setRating($rating = null)
    {
        // validation for constraint: string
        if (!is_null($rating) && !is_string($rating)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($rating, true), gettype($rating)), __LINE__);
        }
        $this->Rating = $rating;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\Award
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
