<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for Delta StructType
 * Meta information extracted from the WSDL
 * - documentation: Incremental amount added to the hurdle rate (e.g. Amount= 20 USD and Ceiling=5, the maximum Delta would be 100 USD).
 * @subpackage Structs
 */
class Delta extends AbstractStructBase
{
    /**
     * The Ceiling
     * Meta information extracted from the WSDL
     * - documentation: Upper limit on the number of Deltas that should be added to the Rate Hurdle for each transient reservation.
     * - use: optional
     * @var int
     */
    public $Ceiling;
    /**
     * The MaxSold
     * Meta information extracted from the WSDL
     * - documentation: Upper limit on the number of transient reservations that should be accepted.
     * - use: optional
     * @var int
     */
    public $MaxSold;
    /**
     * The Amount
     * Meta information extracted from the WSDL
     * - documentation: Specifies an amount, max 3 decimals.
     * - base: xs:decimal
     * - fractionDigits: 3
     * @var float
     */
    public $Amount;
    /**
     * The CurrencyCode
     * Meta information extracted from the WSDL
     * - documentation: Used for an Alpha String, length exactly 3.
     * - base: xs:string
     * - pattern: [a-zA-Z]{3}
     * @var string
     */
    public $CurrencyCode;
    /**
     * The DecimalPlaces
     * @var int
     */
    public $DecimalPlaces;
    /**
     * Constructor method for Delta
     * @uses Delta::setCeiling()
     * @uses Delta::setMaxSold()
     * @uses Delta::setAmount()
     * @uses Delta::setCurrencyCode()
     * @uses Delta::setDecimalPlaces()
     * @param int $ceiling
     * @param int $maxSold
     * @param float $amount
     * @param string $currencyCode
     * @param int $decimalPlaces
     */
    public function __construct($ceiling = null, $maxSold = null, $amount = null, $currencyCode = null, $decimalPlaces = null)
    {
        $this
            ->setCeiling($ceiling)
            ->setMaxSold($maxSold)
            ->setAmount($amount)
            ->setCurrencyCode($currencyCode)
            ->setDecimalPlaces($decimalPlaces);
    }
    /**
     * Get Ceiling value
     * @return int|null
     */
    public function getCeiling()
    {
        return $this->Ceiling;
    }
    /**
     * Set Ceiling value
     * @param int $ceiling
     * @return \StructType\Delta
     */
    public function setCeiling($ceiling = null)
    {
        // validation for constraint: int
        if (!is_null($ceiling) && !(is_int($ceiling) || ctype_digit($ceiling))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($ceiling, true), gettype($ceiling)), __LINE__);
        }
        $this->Ceiling = $ceiling;
        return $this;
    }
    /**
     * Get MaxSold value
     * @return int|null
     */
    public function getMaxSold()
    {
        return $this->MaxSold;
    }
    /**
     * Set MaxSold value
     * @param int $maxSold
     * @return \StructType\Delta
     */
    public function setMaxSold($maxSold = null)
    {
        // validation for constraint: int
        if (!is_null($maxSold) && !(is_int($maxSold) || ctype_digit($maxSold))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($maxSold, true), gettype($maxSold)), __LINE__);
        }
        $this->MaxSold = $maxSold;
        return $this;
    }
    /**
     * Get Amount value
     * @return float|null
     */
    public function getAmount()
    {
        return $this->Amount;
    }
    /**
     * Set Amount value
     * @param float $amount
     * @return \StructType\Delta
     */
    public function setAmount($amount = null)
    {
        // validation for constraint: float
        if (!is_null($amount) && !(is_float($amount) || is_numeric($amount))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a float value, %s given', var_export($amount, true), gettype($amount)), __LINE__);
        }
        // validation for constraint: fractionDigits(3)
        if (!is_null($amount) && mb_strlen(mb_substr($amount, mb_strpos($amount, '.') + 1)) > 3) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must at most contain 3 fraction digits, %d given', var_export($amount, true), mb_strlen(mb_substr($amount, mb_strpos($amount, '.') + 1))), __LINE__);
        }
        $this->Amount = $amount;
        return $this;
    }
    /**
     * Get CurrencyCode value
     * @return string|null
     */
    public function getCurrencyCode()
    {
        return $this->CurrencyCode;
    }
    /**
     * Set CurrencyCode value
     * @param string $currencyCode
     * @return \StructType\Delta
     */
    public function setCurrencyCode($currencyCode = null)
    {
        // validation for constraint: string
        if (!is_null($currencyCode) && !is_string($currencyCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($currencyCode, true), gettype($currencyCode)), __LINE__);
        }
        // validation for constraint: pattern([a-zA-Z]{3})
        if (!is_null($currencyCode) && !preg_match('/[a-zA-Z]{3}/', $currencyCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [a-zA-Z]{3}', var_export($currencyCode, true)), __LINE__);
        }
        $this->CurrencyCode = $currencyCode;
        return $this;
    }
    /**
     * Get DecimalPlaces value
     * @return int|null
     */
    public function getDecimalPlaces()
    {
        return $this->DecimalPlaces;
    }
    /**
     * Set DecimalPlaces value
     * @param int $decimalPlaces
     * @return \StructType\Delta
     */
    public function setDecimalPlaces($decimalPlaces = null)
    {
        // validation for constraint: int
        if (!is_null($decimalPlaces) && !(is_int($decimalPlaces) || ctype_digit($decimalPlaces))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($decimalPlaces, true), gettype($decimalPlaces)), __LINE__);
        }
        $this->DecimalPlaces = $decimalPlaces;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\Delta
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
