<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for DocumentType StructType
 * Meta information extracted from the WSDL
 * - documentation: The effective and expiry date of the document. | The birth date of the document holder. | The gender of the document holder. | Allows for control of the sharing of document data between parties. | Provides information on a specific
 * document.
 * @subpackage Structs
 */
class DocumentType extends AbstractStructBase
{
    /**
     * The DocHolderName
     * Meta information extracted from the WSDL
     * - documentation: The name of the document holder in unformatted text (Mr. Sam Jones). | Used for Character Strings, length 1 to 64.
     * - base: xs:string
     * - choice: DocHolderName | DocHolderFormattedName
     * - choiceMaxOccurs: 1
     * - choiceMinOccurs: 0
     * - maxLength: 64
     * - minLength: 1
     * - minOccurs: 0
     * @var string
     */
    public $DocHolderName;
    /**
     * The DocHolderFormattedName
     * Meta information extracted from the WSDL
     * - documentation: The name of document holder in formatted text.
     * - choice: DocHolderName | DocHolderFormattedName
     * - choiceMaxOccurs: 1
     * - choiceMinOccurs: 0
     * - minOccurs: 0
     * @var \StructType\PersonNameType
     */
    public $DocHolderFormattedName;
    /**
     * The DocLimitations
     * Meta information extracted from the WSDL
     * - documentation: Used to indicate any limitations on the document (e.g. as a person may only be allowed to spend a max of 30 days in country on a visitor's visa). | Used for Character Strings, length 1 to 64.
     * - base: xs:string
     * - maxLength: 64
     * - maxOccurs: 9
     * - minLength: 1
     * - minOccurs: 0
     * @var string[]
     */
    public $DocLimitations;
    /**
     * The AdditionalPersonNames
     * Meta information extracted from the WSDL
     * - minOccurs: 0
     * @var \StructType\AdditionalPersonNames
     */
    public $AdditionalPersonNames;
    /**
     * The DocIssueAuthority
     * Meta information extracted from the WSDL
     * - documentation: Indicates the group or association that granted the document. | Used for Character Strings, length 1 to 64.
     * - base: xs:string
     * - maxLength: 64
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $DocIssueAuthority;
    /**
     * The DocIssueLocation
     * Meta information extracted from the WSDL
     * - documentation: Indicates the location where the document was issued. | Used for Character Strings, length 1 to 64.
     * - base: xs:string
     * - maxLength: 64
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $DocIssueLocation;
    /**
     * The DocID
     * Meta information extracted from the WSDL
     * - documentation: Unique number assigned by authorities to document. | Used for Character Strings, length 1 to 32.
     * - base: xs:string
     * - maxLength: 32
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $DocID;
    /**
     * The DocType
     * Meta information extracted from the WSDL
     * - documentation: Indicates the type of document (e.g. Passport, Military ID, Drivers License, national ID, Vaccination Certificate). Refer to OpenTravel Code List Document Type (DOC). | Used for codes in the OpenTravel Code tables. Possible values of
     * this pattern are 1, 101, 101.EQP, or 101.EQP.X.
     * - base: xs:string
     * - pattern: [0-9A-Z]{1,3}(\.[A-Z]{3}(\.X){0,1}){0,1}
     * - use: optional
     * @var string
     */
    public $DocType;
    /**
     * The DocIssueStateProv
     * Meta information extracted from the WSDL
     * - documentation: State or Province where the document was issued. | Used for Character Strings, length 1 to 8. | The standard code or abbreviation for the state, province, or region.
     * - base: StringLength1to8
     * - maxLength: 8
     * - minLength: 2
     * - use: optional
     * @var string
     */
    public $DocIssueStateProv;
    /**
     * The DocIssueCountry
     * Meta information extracted from the WSDL
     * - documentation: Country where the document was issued. | Specifies a 2 character country code as defined in ISO3166.
     * - base: xs:string
     * - pattern: [a-zA-Z]{2}
     * - use: optional
     * @var string
     */
    public $DocIssueCountry;
    /**
     * The BirthCountry
     * Meta information extracted from the WSDL
     * - documentation: Specifies the birth country of the document holder. | Specifies a 2 character country code as defined in ISO3166.
     * - base: xs:string
     * - pattern: [a-zA-Z]{2}
     * - use: optional
     * @var string
     */
    public $BirthCountry;
    /**
     * The BirthPlace
     * Meta information extracted from the WSDL
     * - documentation: Specifies the birth place of the document holder (e.g., city, state, county, province), when designating a country of birth, use BirthCountry. | Used for Character Strings, length 1 to 64.
     * - base: xs:string
     * - maxLength: 64
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $BirthPlace;
    /**
     * The DocHolderNationality
     * Meta information extracted from the WSDL
     * - documentation: The country code of the nationality of the document holder. | Specifies a 2 character country code as defined in ISO3166.
     * - base: xs:string
     * - pattern: [a-zA-Z]{2}
     * - use: optional
     * @var string
     */
    public $DocHolderNationality;
    /**
     * The ContactName
     * Meta information extracted from the WSDL
     * - documentation: Provides contact name associated with the document. | Used for Character Strings, length 1 to 64.
     * - base: xs:string
     * - maxLength: 64
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $ContactName;
    /**
     * The HolderType
     * Meta information extracted from the WSDL
     * - use: optional
     * @var string
     */
    public $HolderType;
    /**
     * The Remark
     * Meta information extracted from the WSDL
     * - documentation: A remark associated with the document. | Used for Character Strings, length 1 to 128.
     * - base: xs:string
     * - maxLength: 128
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $Remark;
    /**
     * The PostalCode
     * Meta information extracted from the WSDL
     * - documentation: Defines the postal code (e.g., ZIP code) on the document. | Used for Character Strings, length 1 to 16.
     * - base: xs:string
     * - maxLength: 16
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $PostalCode;
    /**
     * The ShareSynchInd
     * @var string
     */
    public $ShareSynchInd;
    /**
     * The ShareMarketInd
     * @var string
     */
    public $ShareMarketInd;
    /**
     * The Gender
     * @var string
     */
    public $Gender;
    /**
     * The BirthDate
     * Meta information extracted from the WSDL
     * - documentation: Indicates the date of birth as indicated in the document, in ISO 8601 prescribed format.
     * - type: xs:date
     * - use: optional
     * @var string
     */
    public $BirthDate;
    /**
     * The EffectiveDate
     * Meta information extracted from the WSDL
     * - documentation: Indicates the starting date.
     * - type: xs:date
     * - use: optional
     * @var string
     */
    public $EffectiveDate;
    /**
     * The ExpireDate
     * Meta information extracted from the WSDL
     * - documentation: Indicates the ending date.
     * - type: xs:date
     * - use: optional
     * @var string
     */
    public $ExpireDate;
    /**
     * The ExpireDateExclusiveIndicator
     * Meta information extracted from the WSDL
     * - documentation: When true, indicates that the ExpireDate is the first day after the applicable period (e.g. when expire date is Oct 15 the last date of the period is Oct 14).
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $ExpireDateExclusiveIndicator;
    /**
     * Constructor method for DocumentType
     * @uses DocumentType::setDocHolderName()
     * @uses DocumentType::setDocHolderFormattedName()
     * @uses DocumentType::setDocLimitations()
     * @uses DocumentType::setAdditionalPersonNames()
     * @uses DocumentType::setDocIssueAuthority()
     * @uses DocumentType::setDocIssueLocation()
     * @uses DocumentType::setDocID()
     * @uses DocumentType::setDocType()
     * @uses DocumentType::setDocIssueStateProv()
     * @uses DocumentType::setDocIssueCountry()
     * @uses DocumentType::setBirthCountry()
     * @uses DocumentType::setBirthPlace()
     * @uses DocumentType::setDocHolderNationality()
     * @uses DocumentType::setContactName()
     * @uses DocumentType::setHolderType()
     * @uses DocumentType::setRemark()
     * @uses DocumentType::setPostalCode()
     * @uses DocumentType::setShareSynchInd()
     * @uses DocumentType::setShareMarketInd()
     * @uses DocumentType::setGender()
     * @uses DocumentType::setBirthDate()
     * @uses DocumentType::setEffectiveDate()
     * @uses DocumentType::setExpireDate()
     * @uses DocumentType::setExpireDateExclusiveIndicator()
     * @param string $docHolderName
     * @param \StructType\PersonNameType $docHolderFormattedName
     * @param string[] $docLimitations
     * @param \StructType\AdditionalPersonNames $additionalPersonNames
     * @param string $docIssueAuthority
     * @param string $docIssueLocation
     * @param string $docID
     * @param string $docType
     * @param string $docIssueStateProv
     * @param string $docIssueCountry
     * @param string $birthCountry
     * @param string $birthPlace
     * @param string $docHolderNationality
     * @param string $contactName
     * @param string $holderType
     * @param string $remark
     * @param string $postalCode
     * @param string $shareSynchInd
     * @param string $shareMarketInd
     * @param string $gender
     * @param string $birthDate
     * @param string $effectiveDate
     * @param string $expireDate
     * @param bool $expireDateExclusiveIndicator
     */
    public function __construct($docHolderName = null, \StructType\PersonNameType $docHolderFormattedName = null, array $docLimitations = array(), \StructType\AdditionalPersonNames $additionalPersonNames = null, $docIssueAuthority = null, $docIssueLocation = null, $docID = null, $docType = null, $docIssueStateProv = null, $docIssueCountry = null, $birthCountry = null, $birthPlace = null, $docHolderNationality = null, $contactName = null, $holderType = null, $remark = null, $postalCode = null, $shareSynchInd = null, $shareMarketInd = null, $gender = null, $birthDate = null, $effectiveDate = null, $expireDate = null, $expireDateExclusiveIndicator = null)
    {
        $this
            ->setDocHolderName($docHolderName)
            ->setDocHolderFormattedName($docHolderFormattedName)
            ->setDocLimitations($docLimitations)
            ->setAdditionalPersonNames($additionalPersonNames)
            ->setDocIssueAuthority($docIssueAuthority)
            ->setDocIssueLocation($docIssueLocation)
            ->setDocID($docID)
            ->setDocType($docType)
            ->setDocIssueStateProv($docIssueStateProv)
            ->setDocIssueCountry($docIssueCountry)
            ->setBirthCountry($birthCountry)
            ->setBirthPlace($birthPlace)
            ->setDocHolderNationality($docHolderNationality)
            ->setContactName($contactName)
            ->setHolderType($holderType)
            ->setRemark($remark)
            ->setPostalCode($postalCode)
            ->setShareSynchInd($shareSynchInd)
            ->setShareMarketInd($shareMarketInd)
            ->setGender($gender)
            ->setBirthDate($birthDate)
            ->setEffectiveDate($effectiveDate)
            ->setExpireDate($expireDate)
            ->setExpireDateExclusiveIndicator($expireDateExclusiveIndicator);
    }
    /**
     * Get DocHolderName value
     * @return string|null
     */
    public function getDocHolderName()
    {
        return isset($this->DocHolderName) ? $this->DocHolderName : null;
    }
    /**
     * This method is responsible for validating the value passed to the setDocHolderName method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDocHolderName method
     * This has to validate that the property which is being set is the only one among the given choices
     * @param mixed $value
     * @return string A non-empty message if the values does not match the validation rules
     */
    public function validateDocHolderNameForChoiceConstraintsFromSetDocHolderName($value)
    {
        $message = '';
        if (is_null($value)) {
            return $message;
        }
        $properties = [
            'DocHolderFormattedName',
        ];
        try {
            foreach ($properties as $property) {
                if (isset($this->{$property})) {
                    throw new \InvalidArgumentException(sprintf('The property DocHolderName can\'t be set as the property %s is already set. Only one property must be set among these properties: DocHolderName, %s.', $property, implode(', ', $properties)), __LINE__);
                }
            }
        } catch (\InvalidArgumentException $e) {
            $message = $e->getMessage();
        }
        return $message;
    }
    /**
     * Set DocHolderName value
     * This property belongs to a choice that allows only one property to exist. It is
     * therefore removable from the request, consequently if the value assigned to this
     * property is null, the property is removed from this object
     * @throws \InvalidArgumentException
     * @param string $docHolderName
     * @return \StructType\DocumentType
     */
    public function setDocHolderName($docHolderName = null)
    {
        // validation for constraint: string
        if (!is_null($docHolderName) && !is_string($docHolderName)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docHolderName, true), gettype($docHolderName)), __LINE__);
        }
        // validation for constraint: choice(DocHolderName, DocHolderFormattedName)
        if ('' !== ($docHolderNameChoiceErrorMessage = self::validateDocHolderNameForChoiceConstraintsFromSetDocHolderName($docHolderName))) {
            throw new \InvalidArgumentException($docHolderNameChoiceErrorMessage, __LINE__);
        }
        // validation for constraint: maxLength(64)
        if (!is_null($docHolderName) && mb_strlen($docHolderName) > 64) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 64', mb_strlen($docHolderName)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($docHolderName) && mb_strlen($docHolderName) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($docHolderName)), __LINE__);
        }
        if (is_null($docHolderName) || (is_array($docHolderName) && empty($docHolderName))) {
            unset($this->DocHolderName);
        } else {
            $this->DocHolderName = $docHolderName;
        }
        return $this;
    }
    /**
     * Get DocHolderFormattedName value
     * @return \StructType\PersonNameType|null
     */
    public function getDocHolderFormattedName()
    {
        return isset($this->DocHolderFormattedName) ? $this->DocHolderFormattedName : null;
    }
    /**
     * This method is responsible for validating the value passed to the setDocHolderFormattedName method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDocHolderFormattedName method
     * This has to validate that the property which is being set is the only one among the given choices
     * @param mixed $value
     * @return string A non-empty message if the values does not match the validation rules
     */
    public function validateDocHolderFormattedNameForChoiceConstraintsFromSetDocHolderFormattedName($value)
    {
        $message = '';
        if (is_null($value)) {
            return $message;
        }
        $properties = [
            'DocHolderName',
        ];
        try {
            foreach ($properties as $property) {
                if (isset($this->{$property})) {
                    throw new \InvalidArgumentException(sprintf('The property DocHolderFormattedName can\'t be set as the property %s is already set. Only one property must be set among these properties: DocHolderFormattedName, %s.', $property, implode(', ', $properties)), __LINE__);
                }
            }
        } catch (\InvalidArgumentException $e) {
            $message = $e->getMessage();
        }
        return $message;
    }
    /**
     * Set DocHolderFormattedName value
     * This property belongs to a choice that allows only one property to exist. It is
     * therefore removable from the request, consequently if the value assigned to this
     * property is null, the property is removed from this object
     * @throws \InvalidArgumentException
     * @param \StructType\PersonNameType $docHolderFormattedName
     * @return \StructType\DocumentType
     */
    public function setDocHolderFormattedName(\StructType\PersonNameType $docHolderFormattedName = null)
    {
        // validation for constraint: choice(DocHolderName, DocHolderFormattedName)
        if ('' !== ($docHolderFormattedNameChoiceErrorMessage = self::validateDocHolderFormattedNameForChoiceConstraintsFromSetDocHolderFormattedName($docHolderFormattedName))) {
            throw new \InvalidArgumentException($docHolderFormattedNameChoiceErrorMessage, __LINE__);
        }
        if (is_null($docHolderFormattedName) || (is_array($docHolderFormattedName) && empty($docHolderFormattedName))) {
            unset($this->DocHolderFormattedName);
        } else {
            $this->DocHolderFormattedName = $docHolderFormattedName;
        }
        return $this;
    }
    /**
     * Get DocLimitations value
     * @return string[]|null
     */
    public function getDocLimitations()
    {
        return $this->DocLimitations;
    }
    /**
     * This method is responsible for validating the values passed to the setDocLimitations method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDocLimitations method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateDocLimitationsForArrayConstraintsFromSetDocLimitations(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $documentTypeDocLimitationsItem) {
            // validation for constraint: itemType
            if (!is_string($documentTypeDocLimitationsItem)) {
                $invalidValues[] = is_object($documentTypeDocLimitationsItem) ? get_class($documentTypeDocLimitationsItem) : sprintf('%s(%s)', gettype($documentTypeDocLimitationsItem), var_export($documentTypeDocLimitationsItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The DocLimitations property can only contain items of type string, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * This method is responsible for validating the value passed to the setDocLimitations method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDocLimitations method
     * This has to validate that the items contained by the array match the length constraint
     * @param mixed $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateDocLimitationsForMaxLengthConstraintFromSetDocLimitations($values)
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $documentTypeDocLimitationsItem) {
            // validation for constraint: maxLength(64)
            if (mb_strlen($documentTypeDocLimitationsItem) > 64) {
                $invalidValues[] = var_export($documentTypeDocLimitationsItem, true);
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('Invalid length for value(s) %s, the number of characters/octets contained by the literal must be less than or equal to 64', implode(', ', $invalidValues));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * This method is responsible for validating the value passed to the setDocLimitations method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDocLimitations method
     * This has to validate that the items contained by the array match the length constraint
     * @param mixed $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateDocLimitationsForMinLengthConstraintFromSetDocLimitations($values)
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $documentTypeDocLimitationsItem) {
            // validation for constraint: minLength(1)
            if (mb_strlen($documentTypeDocLimitationsItem) < 1) {
                $invalidValues[] = var_export($documentTypeDocLimitationsItem, true);
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('Invalid length for value(s) %s, the number of characters/octets contained by the literal must be greater than or equal to 1', implode(', ', $invalidValues));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set DocLimitations value
     * @throws \InvalidArgumentException
     * @param string[] $docLimitations
     * @return \StructType\DocumentType
     */
    public function setDocLimitations(array $docLimitations = array())
    {
        // validation for constraint: array
        if ('' !== ($docLimitationsArrayErrorMessage = self::validateDocLimitationsForArrayConstraintsFromSetDocLimitations($docLimitations))) {
            throw new \InvalidArgumentException($docLimitationsArrayErrorMessage, __LINE__);
        }
        // validation for constraint: maxLength(64)
        if ('' !== ($docLimitationsMaxLengthErrorMessage = self::validateDocLimitationsForMaxLengthConstraintFromSetDocLimitations($docLimitations))) {
            throw new \InvalidArgumentException($docLimitationsMaxLengthErrorMessage, __LINE__);
        }
        // validation for constraint: maxOccurs(9)
        if (is_array($docLimitations) && count($docLimitations) > 9) {
            throw new \InvalidArgumentException(sprintf('Invalid count of %s, the number of elements contained by the property must be less than or equal to 9', count($docLimitations)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if ('' !== ($docLimitationsMinLengthErrorMessage = self::validateDocLimitationsForMinLengthConstraintFromSetDocLimitations($docLimitations))) {
            throw new \InvalidArgumentException($docLimitationsMinLengthErrorMessage, __LINE__);
        }
        $this->DocLimitations = $docLimitations;
        return $this;
    }
    /**
     * Add item to DocLimitations value
     * @throws \InvalidArgumentException
     * @param string $item
     * @return \StructType\DocumentType
     */
    public function addToDocLimitations($item)
    {
        // validation for constraint: itemType
        if (!is_string($item)) {
            throw new \InvalidArgumentException(sprintf('The DocLimitations property can only contain items of type string, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        // validation for constraint: maxLength(64)
        if (mb_strlen($item) > 64) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 64', mb_strlen($item)), __LINE__);
        }
        // validation for constraint: maxOccurs(9)
        if (is_array($this->DocLimitations) && count($this->DocLimitations) >= 9) {
            throw new \InvalidArgumentException(sprintf('You can\'t add anymore element to this property that already contains %s elements, the number of elements contained by the property must be less than or equal to 9', count($this->DocLimitations)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (mb_strlen($item) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($item)), __LINE__);
        }
        $this->DocLimitations[] = $item;
        return $this;
    }
    /**
     * Get AdditionalPersonNames value
     * @return \StructType\AdditionalPersonNames|null
     */
    public function getAdditionalPersonNames()
    {
        return $this->AdditionalPersonNames;
    }
    /**
     * Set AdditionalPersonNames value
     * @param \StructType\AdditionalPersonNames $additionalPersonNames
     * @return \StructType\DocumentType
     */
    public function setAdditionalPersonNames(\StructType\AdditionalPersonNames $additionalPersonNames = null)
    {
        $this->AdditionalPersonNames = $additionalPersonNames;
        return $this;
    }
    /**
     * Get DocIssueAuthority value
     * @return string|null
     */
    public function getDocIssueAuthority()
    {
        return $this->DocIssueAuthority;
    }
    /**
     * Set DocIssueAuthority value
     * @param string $docIssueAuthority
     * @return \StructType\DocumentType
     */
    public function setDocIssueAuthority($docIssueAuthority = null)
    {
        // validation for constraint: string
        if (!is_null($docIssueAuthority) && !is_string($docIssueAuthority)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docIssueAuthority, true), gettype($docIssueAuthority)), __LINE__);
        }
        // validation for constraint: maxLength(64)
        if (!is_null($docIssueAuthority) && mb_strlen($docIssueAuthority) > 64) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 64', mb_strlen($docIssueAuthority)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($docIssueAuthority) && mb_strlen($docIssueAuthority) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($docIssueAuthority)), __LINE__);
        }
        $this->DocIssueAuthority = $docIssueAuthority;
        return $this;
    }
    /**
     * Get DocIssueLocation value
     * @return string|null
     */
    public function getDocIssueLocation()
    {
        return $this->DocIssueLocation;
    }
    /**
     * Set DocIssueLocation value
     * @param string $docIssueLocation
     * @return \StructType\DocumentType
     */
    public function setDocIssueLocation($docIssueLocation = null)
    {
        // validation for constraint: string
        if (!is_null($docIssueLocation) && !is_string($docIssueLocation)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docIssueLocation, true), gettype($docIssueLocation)), __LINE__);
        }
        // validation for constraint: maxLength(64)
        if (!is_null($docIssueLocation) && mb_strlen($docIssueLocation) > 64) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 64', mb_strlen($docIssueLocation)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($docIssueLocation) && mb_strlen($docIssueLocation) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($docIssueLocation)), __LINE__);
        }
        $this->DocIssueLocation = $docIssueLocation;
        return $this;
    }
    /**
     * Get DocID value
     * @return string|null
     */
    public function getDocID()
    {
        return $this->DocID;
    }
    /**
     * Set DocID value
     * @param string $docID
     * @return \StructType\DocumentType
     */
    public function setDocID($docID = null)
    {
        // validation for constraint: string
        if (!is_null($docID) && !is_string($docID)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docID, true), gettype($docID)), __LINE__);
        }
        // validation for constraint: maxLength(32)
        if (!is_null($docID) && mb_strlen($docID) > 32) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 32', mb_strlen($docID)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($docID) && mb_strlen($docID) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($docID)), __LINE__);
        }
        $this->DocID = $docID;
        return $this;
    }
    /**
     * Get DocType value
     * @return string|null
     */
    public function getDocType()
    {
        return $this->DocType;
    }
    /**
     * Set DocType value
     * @param string $docType
     * @return \StructType\DocumentType
     */
    public function setDocType($docType = null)
    {
        // validation for constraint: string
        if (!is_null($docType) && !is_string($docType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docType, true), gettype($docType)), __LINE__);
        }
        // validation for constraint: pattern([0-9A-Z]{1,3}(\.[A-Z]{3}(\.X){0,1}){0,1})
        if (!is_null($docType) && !preg_match('/[0-9A-Z]{1,3}(\\.[A-Z]{3}(\\.X){0,1}){0,1}/', $docType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [0-9A-Z]{1,3}(\.[A-Z]{3}(\.X){0,1}){0,1}', var_export($docType, true)), __LINE__);
        }
        $this->DocType = $docType;
        return $this;
    }
    /**
     * Get DocIssueStateProv value
     * @return string|null
     */
    public function getDocIssueStateProv()
    {
        return $this->DocIssueStateProv;
    }
    /**
     * Set DocIssueStateProv value
     * @param string $docIssueStateProv
     * @return \StructType\DocumentType
     */
    public function setDocIssueStateProv($docIssueStateProv = null)
    {
        // validation for constraint: string
        if (!is_null($docIssueStateProv) && !is_string($docIssueStateProv)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docIssueStateProv, true), gettype($docIssueStateProv)), __LINE__);
        }
        // validation for constraint: maxLength(8)
        if (!is_null($docIssueStateProv) && mb_strlen($docIssueStateProv) > 8) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 8', mb_strlen($docIssueStateProv)), __LINE__);
        }
        // validation for constraint: minLength(2)
        if (!is_null($docIssueStateProv) && mb_strlen($docIssueStateProv) < 2) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 2', mb_strlen($docIssueStateProv)), __LINE__);
        }
        $this->DocIssueStateProv = $docIssueStateProv;
        return $this;
    }
    /**
     * Get DocIssueCountry value
     * @return string|null
     */
    public function getDocIssueCountry()
    {
        return $this->DocIssueCountry;
    }
    /**
     * Set DocIssueCountry value
     * @param string $docIssueCountry
     * @return \StructType\DocumentType
     */
    public function setDocIssueCountry($docIssueCountry = null)
    {
        // validation for constraint: string
        if (!is_null($docIssueCountry) && !is_string($docIssueCountry)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docIssueCountry, true), gettype($docIssueCountry)), __LINE__);
        }
        // validation for constraint: pattern([a-zA-Z]{2})
        if (!is_null($docIssueCountry) && !preg_match('/[a-zA-Z]{2}/', $docIssueCountry)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [a-zA-Z]{2}', var_export($docIssueCountry, true)), __LINE__);
        }
        $this->DocIssueCountry = $docIssueCountry;
        return $this;
    }
    /**
     * Get BirthCountry value
     * @return string|null
     */
    public function getBirthCountry()
    {
        return $this->BirthCountry;
    }
    /**
     * Set BirthCountry value
     * @param string $birthCountry
     * @return \StructType\DocumentType
     */
    public function setBirthCountry($birthCountry = null)
    {
        // validation for constraint: string
        if (!is_null($birthCountry) && !is_string($birthCountry)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($birthCountry, true), gettype($birthCountry)), __LINE__);
        }
        // validation for constraint: pattern([a-zA-Z]{2})
        if (!is_null($birthCountry) && !preg_match('/[a-zA-Z]{2}/', $birthCountry)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [a-zA-Z]{2}', var_export($birthCountry, true)), __LINE__);
        }
        $this->BirthCountry = $birthCountry;
        return $this;
    }
    /**
     * Get BirthPlace value
     * @return string|null
     */
    public function getBirthPlace()
    {
        return $this->BirthPlace;
    }
    /**
     * Set BirthPlace value
     * @param string $birthPlace
     * @return \StructType\DocumentType
     */
    public function setBirthPlace($birthPlace = null)
    {
        // validation for constraint: string
        if (!is_null($birthPlace) && !is_string($birthPlace)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($birthPlace, true), gettype($birthPlace)), __LINE__);
        }
        // validation for constraint: maxLength(64)
        if (!is_null($birthPlace) && mb_strlen($birthPlace) > 64) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 64', mb_strlen($birthPlace)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($birthPlace) && mb_strlen($birthPlace) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($birthPlace)), __LINE__);
        }
        $this->BirthPlace = $birthPlace;
        return $this;
    }
    /**
     * Get DocHolderNationality value
     * @return string|null
     */
    public function getDocHolderNationality()
    {
        return $this->DocHolderNationality;
    }
    /**
     * Set DocHolderNationality value
     * @param string $docHolderNationality
     * @return \StructType\DocumentType
     */
    public function setDocHolderNationality($docHolderNationality = null)
    {
        // validation for constraint: string
        if (!is_null($docHolderNationality) && !is_string($docHolderNationality)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($docHolderNationality, true), gettype($docHolderNationality)), __LINE__);
        }
        // validation for constraint: pattern([a-zA-Z]{2})
        if (!is_null($docHolderNationality) && !preg_match('/[a-zA-Z]{2}/', $docHolderNationality)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [a-zA-Z]{2}', var_export($docHolderNationality, true)), __LINE__);
        }
        $this->DocHolderNationality = $docHolderNationality;
        return $this;
    }
    /**
     * Get ContactName value
     * @return string|null
     */
    public function getContactName()
    {
        return $this->ContactName;
    }
    /**
     * Set ContactName value
     * @param string $contactName
     * @return \StructType\DocumentType
     */
    public function setContactName($contactName = null)
    {
        // validation for constraint: string
        if (!is_null($contactName) && !is_string($contactName)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($contactName, true), gettype($contactName)), __LINE__);
        }
        // validation for constraint: maxLength(64)
        if (!is_null($contactName) && mb_strlen($contactName) > 64) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 64', mb_strlen($contactName)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($contactName) && mb_strlen($contactName) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($contactName)), __LINE__);
        }
        $this->ContactName = $contactName;
        return $this;
    }
    /**
     * Get HolderType value
     * @return string|null
     */
    public function getHolderType()
    {
        return $this->HolderType;
    }
    /**
     * Set HolderType value
     * @param string $holderType
     * @return \StructType\DocumentType
     */
    public function setHolderType($holderType = null)
    {
        // validation for constraint: string
        if (!is_null($holderType) && !is_string($holderType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($holderType, true), gettype($holderType)), __LINE__);
        }
        $this->HolderType = $holderType;
        return $this;
    }
    /**
     * Get Remark value
     * @return string|null
     */
    public function getRemark()
    {
        return $this->Remark;
    }
    /**
     * Set Remark value
     * @param string $remark
     * @return \StructType\DocumentType
     */
    public function setRemark($remark = null)
    {
        // validation for constraint: string
        if (!is_null($remark) && !is_string($remark)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($remark, true), gettype($remark)), __LINE__);
        }
        // validation for constraint: maxLength(128)
        if (!is_null($remark) && mb_strlen($remark) > 128) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 128', mb_strlen($remark)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($remark) && mb_strlen($remark) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($remark)), __LINE__);
        }
        $this->Remark = $remark;
        return $this;
    }
    /**
     * Get PostalCode value
     * @return string|null
     */
    public function getPostalCode()
    {
        return $this->PostalCode;
    }
    /**
     * Set PostalCode value
     * @param string $postalCode
     * @return \StructType\DocumentType
     */
    public function setPostalCode($postalCode = null)
    {
        // validation for constraint: string
        if (!is_null($postalCode) && !is_string($postalCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($postalCode, true), gettype($postalCode)), __LINE__);
        }
        // validation for constraint: maxLength(16)
        if (!is_null($postalCode) && mb_strlen($postalCode) > 16) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 16', mb_strlen($postalCode)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($postalCode) && mb_strlen($postalCode) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($postalCode)), __LINE__);
        }
        $this->PostalCode = $postalCode;
        return $this;
    }
    /**
     * Get ShareSynchInd value
     * @return string|null
     */
    public function getShareSynchInd()
    {
        return $this->ShareSynchInd;
    }
    /**
     * Set ShareSynchInd value
     * @param string $shareSynchInd
     * @return \StructType\DocumentType
     */
    public function setShareSynchInd($shareSynchInd = null)
    {
        // validation for constraint: string
        if (!is_null($shareSynchInd) && !is_string($shareSynchInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shareSynchInd, true), gettype($shareSynchInd)), __LINE__);
        }
        $this->ShareSynchInd = $shareSynchInd;
        return $this;
    }
    /**
     * Get ShareMarketInd value
     * @return string|null
     */
    public function getShareMarketInd()
    {
        return $this->ShareMarketInd;
    }
    /**
     * Set ShareMarketInd value
     * @param string $shareMarketInd
     * @return \StructType\DocumentType
     */
    public function setShareMarketInd($shareMarketInd = null)
    {
        // validation for constraint: string
        if (!is_null($shareMarketInd) && !is_string($shareMarketInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shareMarketInd, true), gettype($shareMarketInd)), __LINE__);
        }
        $this->ShareMarketInd = $shareMarketInd;
        return $this;
    }
    /**
     * Get Gender value
     * @return string|null
     */
    public function getGender()
    {
        return $this->Gender;
    }
    /**
     * Set Gender value
     * @param string $gender
     * @return \StructType\DocumentType
     */
    public function setGender($gender = null)
    {
        // validation for constraint: string
        if (!is_null($gender) && !is_string($gender)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($gender, true), gettype($gender)), __LINE__);
        }
        $this->Gender = $gender;
        return $this;
    }
    /**
     * Get BirthDate value
     * @return string|null
     */
    public function getBirthDate()
    {
        return $this->BirthDate;
    }
    /**
     * Set BirthDate value
     * @param string $birthDate
     * @return \StructType\DocumentType
     */
    public function setBirthDate($birthDate = null)
    {
        // validation for constraint: string
        if (!is_null($birthDate) && !is_string($birthDate)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($birthDate, true), gettype($birthDate)), __LINE__);
        }
        $this->BirthDate = $birthDate;
        return $this;
    }
    /**
     * Get EffectiveDate value
     * @return string|null
     */
    public function getEffectiveDate()
    {
        return $this->EffectiveDate;
    }
    /**
     * Set EffectiveDate value
     * @param string $effectiveDate
     * @return \StructType\DocumentType
     */
    public function setEffectiveDate($effectiveDate = null)
    {
        // validation for constraint: string
        if (!is_null($effectiveDate) && !is_string($effectiveDate)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($effectiveDate, true), gettype($effectiveDate)), __LINE__);
        }
        $this->EffectiveDate = $effectiveDate;
        return $this;
    }
    /**
     * Get ExpireDate value
     * @return string|null
     */
    public function getExpireDate()
    {
        return $this->ExpireDate;
    }
    /**
     * Set ExpireDate value
     * @param string $expireDate
     * @return \StructType\DocumentType
     */
    public function setExpireDate($expireDate = null)
    {
        // validation for constraint: string
        if (!is_null($expireDate) && !is_string($expireDate)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($expireDate, true), gettype($expireDate)), __LINE__);
        }
        $this->ExpireDate = $expireDate;
        return $this;
    }
    /**
     * Get ExpireDateExclusiveIndicator value
     * @return bool|null
     */
    public function getExpireDateExclusiveIndicator()
    {
        return $this->ExpireDateExclusiveIndicator;
    }
    /**
     * Set ExpireDateExclusiveIndicator value
     * @param bool $expireDateExclusiveIndicator
     * @return \StructType\DocumentType
     */
    public function setExpireDateExclusiveIndicator($expireDateExclusiveIndicator = null)
    {
        // validation for constraint: boolean
        if (!is_null($expireDateExclusiveIndicator) && !is_bool($expireDateExclusiveIndicator)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($expireDateExclusiveIndicator, true), gettype($expireDateExclusiveIndicator)), __LINE__);
        }
        $this->ExpireDateExclusiveIndicator = $expireDateExclusiveIndicator;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\DocumentType
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
