<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for FlightTypePref StructType
 * Meta information extracted from the WSDL
 * - documentation: Defines preferred flight characteristics to be used in a search. | Indicates preferred flight characteristics to be used in a search (e.g., connections, stopovers).
 * @subpackage Structs
 */
class FlightTypePref extends AbstractStructBase
{
    /**
     * The FlightType
     * Meta information extracted from the WSDL
     * - documentation: Indicates type of stops preferred (Nonstop, Direct, Connection).
     * - type: FlightTypeType
     * - use: optional
     * @var string
     */
    public $FlightType;
    /**
     * The MaxConnections
     * Meta information extracted from the WSDL
     * - documentation: Indicates that if connection is chosen, then this attribute defines the maximum number of connections preferred.
     * - type: xs:nonNegativeInteger
     * - use: optional
     * @var int
     */
    public $MaxConnections;
    /**
     * The NonScheduledFltInfo
     * @var string
     */
    public $NonScheduledFltInfo;
    /**
     * The BackhaulIndicator
     * Meta information extracted from the WSDL
     * - documentation: If true, include connections where one of the enroute stops is the same as the initial board point or the final off point of the flight.
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $BackhaulIndicator;
    /**
     * The GroundTransportIndicator
     * Meta information extracted from the WSDL
     * - documentation: If true, include flights that include at least one leg that is ground transportation.
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $GroundTransportIndicator;
    /**
     * The DirectAndNonStopOnlyInd
     * Meta information extracted from the WSDL
     * - documentation: If true, direct and non-stop flights are requested.
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $DirectAndNonStopOnlyInd;
    /**
     * The NonStopsOnlyInd
     * Meta information extracted from the WSDL
     * - documentation: If true, only non-stop flights are requested.
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $NonStopsOnlyInd;
    /**
     * The OnlineConnectionsOnlyInd
     * Meta information extracted from the WSDL
     * - documentation: If true, only online connection flights are requested (i.e., same marketing airline).
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $OnlineConnectionsOnlyInd;
    /**
     * The RoutingType
     * @var string
     */
    public $RoutingType;
    /**
     * The ExcludeTrainInd
     * Meta information extracted from the WSDL
     * - documentation: When true, exclude connections that include travel by train for one of the legs.
     * - type: xs:boolean
     * - use: optional
     * @var bool
     */
    public $ExcludeTrainInd;
    /**
     * The PreferLevel
     * @var string
     */
    public $PreferLevel;
    /**
     * Constructor method for FlightTypePref
     * @uses FlightTypePref::setFlightType()
     * @uses FlightTypePref::setMaxConnections()
     * @uses FlightTypePref::setNonScheduledFltInfo()
     * @uses FlightTypePref::setBackhaulIndicator()
     * @uses FlightTypePref::setGroundTransportIndicator()
     * @uses FlightTypePref::setDirectAndNonStopOnlyInd()
     * @uses FlightTypePref::setNonStopsOnlyInd()
     * @uses FlightTypePref::setOnlineConnectionsOnlyInd()
     * @uses FlightTypePref::setRoutingType()
     * @uses FlightTypePref::setExcludeTrainInd()
     * @uses FlightTypePref::setPreferLevel()
     * @param string $flightType
     * @param int $maxConnections
     * @param string $nonScheduledFltInfo
     * @param bool $backhaulIndicator
     * @param bool $groundTransportIndicator
     * @param bool $directAndNonStopOnlyInd
     * @param bool $nonStopsOnlyInd
     * @param bool $onlineConnectionsOnlyInd
     * @param string $routingType
     * @param bool $excludeTrainInd
     * @param string $preferLevel
     */
    public function __construct($flightType = null, $maxConnections = null, $nonScheduledFltInfo = null, $backhaulIndicator = null, $groundTransportIndicator = null, $directAndNonStopOnlyInd = null, $nonStopsOnlyInd = null, $onlineConnectionsOnlyInd = null, $routingType = null, $excludeTrainInd = null, $preferLevel = null)
    {
        $this
            ->setFlightType($flightType)
            ->setMaxConnections($maxConnections)
            ->setNonScheduledFltInfo($nonScheduledFltInfo)
            ->setBackhaulIndicator($backhaulIndicator)
            ->setGroundTransportIndicator($groundTransportIndicator)
            ->setDirectAndNonStopOnlyInd($directAndNonStopOnlyInd)
            ->setNonStopsOnlyInd($nonStopsOnlyInd)
            ->setOnlineConnectionsOnlyInd($onlineConnectionsOnlyInd)
            ->setRoutingType($routingType)
            ->setExcludeTrainInd($excludeTrainInd)
            ->setPreferLevel($preferLevel);
    }
    /**
     * Get FlightType value
     * @return string|null
     */
    public function getFlightType()
    {
        return $this->FlightType;
    }
    /**
     * Set FlightType value
     * @uses \EnumType\FlightTypeType::valueIsValid()
     * @uses \EnumType\FlightTypeType::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $flightType
     * @return \StructType\FlightTypePref
     */
    public function setFlightType($flightType = null)
    {
        // validation for constraint: enumeration
        if (!\EnumType\FlightTypeType::valueIsValid($flightType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \EnumType\FlightTypeType', is_array($flightType) ? implode(', ', $flightType) : var_export($flightType, true), implode(', ', \EnumType\FlightTypeType::getValidValues())), __LINE__);
        }
        $this->FlightType = $flightType;
        return $this;
    }
    /**
     * Get MaxConnections value
     * @return int|null
     */
    public function getMaxConnections()
    {
        return $this->MaxConnections;
    }
    /**
     * Set MaxConnections value
     * @param int $maxConnections
     * @return \StructType\FlightTypePref
     */
    public function setMaxConnections($maxConnections = null)
    {
        // validation for constraint: int
        if (!is_null($maxConnections) && !(is_int($maxConnections) || ctype_digit($maxConnections))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($maxConnections, true), gettype($maxConnections)), __LINE__);
        }
        $this->MaxConnections = $maxConnections;
        return $this;
    }
    /**
     * Get NonScheduledFltInfo value
     * @return string|null
     */
    public function getNonScheduledFltInfo()
    {
        return $this->NonScheduledFltInfo;
    }
    /**
     * Set NonScheduledFltInfo value
     * @param string $nonScheduledFltInfo
     * @return \StructType\FlightTypePref
     */
    public function setNonScheduledFltInfo($nonScheduledFltInfo = null)
    {
        // validation for constraint: string
        if (!is_null($nonScheduledFltInfo) && !is_string($nonScheduledFltInfo)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($nonScheduledFltInfo, true), gettype($nonScheduledFltInfo)), __LINE__);
        }
        $this->NonScheduledFltInfo = $nonScheduledFltInfo;
        return $this;
    }
    /**
     * Get BackhaulIndicator value
     * @return bool|null
     */
    public function getBackhaulIndicator()
    {
        return $this->BackhaulIndicator;
    }
    /**
     * Set BackhaulIndicator value
     * @param bool $backhaulIndicator
     * @return \StructType\FlightTypePref
     */
    public function setBackhaulIndicator($backhaulIndicator = null)
    {
        // validation for constraint: boolean
        if (!is_null($backhaulIndicator) && !is_bool($backhaulIndicator)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($backhaulIndicator, true), gettype($backhaulIndicator)), __LINE__);
        }
        $this->BackhaulIndicator = $backhaulIndicator;
        return $this;
    }
    /**
     * Get GroundTransportIndicator value
     * @return bool|null
     */
    public function getGroundTransportIndicator()
    {
        return $this->GroundTransportIndicator;
    }
    /**
     * Set GroundTransportIndicator value
     * @param bool $groundTransportIndicator
     * @return \StructType\FlightTypePref
     */
    public function setGroundTransportIndicator($groundTransportIndicator = null)
    {
        // validation for constraint: boolean
        if (!is_null($groundTransportIndicator) && !is_bool($groundTransportIndicator)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($groundTransportIndicator, true), gettype($groundTransportIndicator)), __LINE__);
        }
        $this->GroundTransportIndicator = $groundTransportIndicator;
        return $this;
    }
    /**
     * Get DirectAndNonStopOnlyInd value
     * @return bool|null
     */
    public function getDirectAndNonStopOnlyInd()
    {
        return $this->DirectAndNonStopOnlyInd;
    }
    /**
     * Set DirectAndNonStopOnlyInd value
     * @param bool $directAndNonStopOnlyInd
     * @return \StructType\FlightTypePref
     */
    public function setDirectAndNonStopOnlyInd($directAndNonStopOnlyInd = null)
    {
        // validation for constraint: boolean
        if (!is_null($directAndNonStopOnlyInd) && !is_bool($directAndNonStopOnlyInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($directAndNonStopOnlyInd, true), gettype($directAndNonStopOnlyInd)), __LINE__);
        }
        $this->DirectAndNonStopOnlyInd = $directAndNonStopOnlyInd;
        return $this;
    }
    /**
     * Get NonStopsOnlyInd value
     * @return bool|null
     */
    public function getNonStopsOnlyInd()
    {
        return $this->NonStopsOnlyInd;
    }
    /**
     * Set NonStopsOnlyInd value
     * @param bool $nonStopsOnlyInd
     * @return \StructType\FlightTypePref
     */
    public function setNonStopsOnlyInd($nonStopsOnlyInd = null)
    {
        // validation for constraint: boolean
        if (!is_null($nonStopsOnlyInd) && !is_bool($nonStopsOnlyInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($nonStopsOnlyInd, true), gettype($nonStopsOnlyInd)), __LINE__);
        }
        $this->NonStopsOnlyInd = $nonStopsOnlyInd;
        return $this;
    }
    /**
     * Get OnlineConnectionsOnlyInd value
     * @return bool|null
     */
    public function getOnlineConnectionsOnlyInd()
    {
        return $this->OnlineConnectionsOnlyInd;
    }
    /**
     * Set OnlineConnectionsOnlyInd value
     * @param bool $onlineConnectionsOnlyInd
     * @return \StructType\FlightTypePref
     */
    public function setOnlineConnectionsOnlyInd($onlineConnectionsOnlyInd = null)
    {
        // validation for constraint: boolean
        if (!is_null($onlineConnectionsOnlyInd) && !is_bool($onlineConnectionsOnlyInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($onlineConnectionsOnlyInd, true), gettype($onlineConnectionsOnlyInd)), __LINE__);
        }
        $this->OnlineConnectionsOnlyInd = $onlineConnectionsOnlyInd;
        return $this;
    }
    /**
     * Get RoutingType value
     * @return string|null
     */
    public function getRoutingType()
    {
        return $this->RoutingType;
    }
    /**
     * Set RoutingType value
     * @param string $routingType
     * @return \StructType\FlightTypePref
     */
    public function setRoutingType($routingType = null)
    {
        // validation for constraint: string
        if (!is_null($routingType) && !is_string($routingType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($routingType, true), gettype($routingType)), __LINE__);
        }
        $this->RoutingType = $routingType;
        return $this;
    }
    /**
     * Get ExcludeTrainInd value
     * @return bool|null
     */
    public function getExcludeTrainInd()
    {
        return $this->ExcludeTrainInd;
    }
    /**
     * Set ExcludeTrainInd value
     * @param bool $excludeTrainInd
     * @return \StructType\FlightTypePref
     */
    public function setExcludeTrainInd($excludeTrainInd = null)
    {
        // validation for constraint: boolean
        if (!is_null($excludeTrainInd) && !is_bool($excludeTrainInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($excludeTrainInd, true), gettype($excludeTrainInd)), __LINE__);
        }
        $this->ExcludeTrainInd = $excludeTrainInd;
        return $this;
    }
    /**
     * Get PreferLevel value
     * @return string|null
     */
    public function getPreferLevel()
    {
        return $this->PreferLevel;
    }
    /**
     * Set PreferLevel value
     * @uses \EnumType\PreferLevelType::valueIsValid()
     * @uses \EnumType\PreferLevelType::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $preferLevel
     * @return \StructType\FlightTypePref
     */
    public function setPreferLevel($preferLevel = null)
    {
        // validation for constraint: enumeration
        if (!\EnumType\PreferLevelType::valueIsValid($preferLevel)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \EnumType\PreferLevelType', is_array($preferLevel) ? implode(', ', $preferLevel) : var_export($preferLevel, true), implode(', ', \EnumType\PreferLevelType::getValidValues())), __LINE__);
        }
        $this->PreferLevel = $preferLevel;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\FlightTypePref
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
