<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for InsuranceType StructType
 * Meta information extracted from the WSDL
 * - documentation: The effective and expiry dates for this policy. | Allows for control of the sharing of insurance data between parties. | Travel insurance carried by the customer or company.
 * @subpackage Structs
 */
class InsuranceType extends AbstractStructBase
{
    /**
     * The PolicyNumber
     * Meta information extracted from the WSDL
     * - documentation: Identifier assigned by insurance company to the insurance policy. | Used for Character Strings, length 1 to 32.
     * - base: xs:string
     * - maxLength: 32
     * - minLength: 1
     * - use: required
     * @var string
     */
    public $PolicyNumber;
    /**
     * The InsuredName
     * Meta information extracted from the WSDL
     * - documentation: Name of the person insured.
     * - minOccurs: 0
     * @var \StructType\PersonNameType
     */
    public $InsuredName;
    /**
     * The InsuranceCompany
     * Meta information extracted from the WSDL
     * - documentation: Name of the insurance company.
     * - minOccurs: 0
     * @var \StructType\CompanyNameType
     */
    public $InsuranceCompany;
    /**
     * The Underwriter
     * Meta information extracted from the WSDL
     * - documentation: Underwriting company providing coverage.
     * - minOccurs: 0
     * @var \StructType\CompanyNameType
     */
    public $Underwriter;
    /**
     * The InsuranceType
     * Meta information extracted from the WSDL
     * - documentation: Type of insurance policy carried by the individual or company. | Used for Character Strings, length 1 to 32.
     * - base: xs:string
     * - maxLength: 32
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $InsuranceType;
    /**
     * The RPH
     * Meta information extracted from the WSDL
     * - documentation: A unique reference for this insurance policy within this message. | The Reference Place Holder (RPH) is an index code used to identify an instance in a collection of like items (e.g. used to assign individual passengers or clients to
     * particular itinerary items).
     * - base: xs:string
     * - pattern: [0-9]{1,8}
     * - use: optional
     * @var string
     */
    public $RPH;
    /**
     * The ShareSynchInd
     * @var string
     */
    public $ShareSynchInd;
    /**
     * The ShareMarketInd
     * @var string
     */
    public $ShareMarketInd;
    /**
     * The EffectiveDate
     * @var string
     */
    public $EffectiveDate;
    /**
     * The ExpireDate
     * @var string
     */
    public $ExpireDate;
    /**
     * The ExpireDateExclusiveIndicator
     * @var bool
     */
    public $ExpireDateExclusiveIndicator;
    /**
     * Constructor method for InsuranceType
     * @uses InsuranceType::setPolicyNumber()
     * @uses InsuranceType::setInsuredName()
     * @uses InsuranceType::setInsuranceCompany()
     * @uses InsuranceType::setUnderwriter()
     * @uses InsuranceType::setInsuranceType()
     * @uses InsuranceType::setRPH()
     * @uses InsuranceType::setShareSynchInd()
     * @uses InsuranceType::setShareMarketInd()
     * @uses InsuranceType::setEffectiveDate()
     * @uses InsuranceType::setExpireDate()
     * @uses InsuranceType::setExpireDateExclusiveIndicator()
     * @param string $policyNumber
     * @param \StructType\PersonNameType $insuredName
     * @param \StructType\CompanyNameType $insuranceCompany
     * @param \StructType\CompanyNameType $underwriter
     * @param string $insuranceType
     * @param string $rPH
     * @param string $shareSynchInd
     * @param string $shareMarketInd
     * @param string $effectiveDate
     * @param string $expireDate
     * @param bool $expireDateExclusiveIndicator
     */
    public function __construct($policyNumber = null, \StructType\PersonNameType $insuredName = null, \StructType\CompanyNameType $insuranceCompany = null, \StructType\CompanyNameType $underwriter = null, $insuranceType = null, $rPH = null, $shareSynchInd = null, $shareMarketInd = null, $effectiveDate = null, $expireDate = null, $expireDateExclusiveIndicator = null)
    {
        $this
            ->setPolicyNumber($policyNumber)
            ->setInsuredName($insuredName)
            ->setInsuranceCompany($insuranceCompany)
            ->setUnderwriter($underwriter)
            ->setInsuranceType($insuranceType)
            ->setRPH($rPH)
            ->setShareSynchInd($shareSynchInd)
            ->setShareMarketInd($shareMarketInd)
            ->setEffectiveDate($effectiveDate)
            ->setExpireDate($expireDate)
            ->setExpireDateExclusiveIndicator($expireDateExclusiveIndicator);
    }
    /**
     * Get PolicyNumber value
     * @return string
     */
    public function getPolicyNumber()
    {
        return $this->PolicyNumber;
    }
    /**
     * Set PolicyNumber value
     * @param string $policyNumber
     * @return \StructType\InsuranceType
     */
    public function setPolicyNumber($policyNumber = null)
    {
        // validation for constraint: string
        if (!is_null($policyNumber) && !is_string($policyNumber)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($policyNumber, true), gettype($policyNumber)), __LINE__);
        }
        // validation for constraint: maxLength(32)
        if (!is_null($policyNumber) && mb_strlen($policyNumber) > 32) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 32', mb_strlen($policyNumber)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($policyNumber) && mb_strlen($policyNumber) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($policyNumber)), __LINE__);
        }
        $this->PolicyNumber = $policyNumber;
        return $this;
    }
    /**
     * Get InsuredName value
     * @return \StructType\PersonNameType|null
     */
    public function getInsuredName()
    {
        return $this->InsuredName;
    }
    /**
     * Set InsuredName value
     * @param \StructType\PersonNameType $insuredName
     * @return \StructType\InsuranceType
     */
    public function setInsuredName(\StructType\PersonNameType $insuredName = null)
    {
        $this->InsuredName = $insuredName;
        return $this;
    }
    /**
     * Get InsuranceCompany value
     * @return \StructType\CompanyNameType|null
     */
    public function getInsuranceCompany()
    {
        return $this->InsuranceCompany;
    }
    /**
     * Set InsuranceCompany value
     * @param \StructType\CompanyNameType $insuranceCompany
     * @return \StructType\InsuranceType
     */
    public function setInsuranceCompany(\StructType\CompanyNameType $insuranceCompany = null)
    {
        $this->InsuranceCompany = $insuranceCompany;
        return $this;
    }
    /**
     * Get Underwriter value
     * @return \StructType\CompanyNameType|null
     */
    public function getUnderwriter()
    {
        return $this->Underwriter;
    }
    /**
     * Set Underwriter value
     * @param \StructType\CompanyNameType $underwriter
     * @return \StructType\InsuranceType
     */
    public function setUnderwriter(\StructType\CompanyNameType $underwriter = null)
    {
        $this->Underwriter = $underwriter;
        return $this;
    }
    /**
     * Get InsuranceType value
     * @return string|null
     */
    public function getInsuranceType()
    {
        return $this->InsuranceType;
    }
    /**
     * Set InsuranceType value
     * @param string $insuranceType
     * @return \StructType\InsuranceType
     */
    public function setInsuranceType($insuranceType = null)
    {
        // validation for constraint: string
        if (!is_null($insuranceType) && !is_string($insuranceType)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($insuranceType, true), gettype($insuranceType)), __LINE__);
        }
        // validation for constraint: maxLength(32)
        if (!is_null($insuranceType) && mb_strlen($insuranceType) > 32) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 32', mb_strlen($insuranceType)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($insuranceType) && mb_strlen($insuranceType) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($insuranceType)), __LINE__);
        }
        $this->InsuranceType = $insuranceType;
        return $this;
    }
    /**
     * Get RPH value
     * @return string|null
     */
    public function getRPH()
    {
        return $this->RPH;
    }
    /**
     * Set RPH value
     * @param string $rPH
     * @return \StructType\InsuranceType
     */
    public function setRPH($rPH = null)
    {
        // validation for constraint: string
        if (!is_null($rPH) && !is_string($rPH)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($rPH, true), gettype($rPH)), __LINE__);
        }
        // validation for constraint: pattern([0-9]{1,8})
        if (!is_null($rPH) && !preg_match('/[0-9]{1,8}/', $rPH)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [0-9]{1,8}', var_export($rPH, true)), __LINE__);
        }
        $this->RPH = $rPH;
        return $this;
    }
    /**
     * Get ShareSynchInd value
     * @return string|null
     */
    public function getShareSynchInd()
    {
        return $this->ShareSynchInd;
    }
    /**
     * Set ShareSynchInd value
     * @param string $shareSynchInd
     * @return \StructType\InsuranceType
     */
    public function setShareSynchInd($shareSynchInd = null)
    {
        // validation for constraint: string
        if (!is_null($shareSynchInd) && !is_string($shareSynchInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shareSynchInd, true), gettype($shareSynchInd)), __LINE__);
        }
        $this->ShareSynchInd = $shareSynchInd;
        return $this;
    }
    /**
     * Get ShareMarketInd value
     * @return string|null
     */
    public function getShareMarketInd()
    {
        return $this->ShareMarketInd;
    }
    /**
     * Set ShareMarketInd value
     * @param string $shareMarketInd
     * @return \StructType\InsuranceType
     */
    public function setShareMarketInd($shareMarketInd = null)
    {
        // validation for constraint: string
        if (!is_null($shareMarketInd) && !is_string($shareMarketInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shareMarketInd, true), gettype($shareMarketInd)), __LINE__);
        }
        $this->ShareMarketInd = $shareMarketInd;
        return $this;
    }
    /**
     * Get EffectiveDate value
     * @return string|null
     */
    public function getEffectiveDate()
    {
        return $this->EffectiveDate;
    }
    /**
     * Set EffectiveDate value
     * @param string $effectiveDate
     * @return \StructType\InsuranceType
     */
    public function setEffectiveDate($effectiveDate = null)
    {
        // validation for constraint: string
        if (!is_null($effectiveDate) && !is_string($effectiveDate)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($effectiveDate, true), gettype($effectiveDate)), __LINE__);
        }
        $this->EffectiveDate = $effectiveDate;
        return $this;
    }
    /**
     * Get ExpireDate value
     * @return string|null
     */
    public function getExpireDate()
    {
        return $this->ExpireDate;
    }
    /**
     * Set ExpireDate value
     * @param string $expireDate
     * @return \StructType\InsuranceType
     */
    public function setExpireDate($expireDate = null)
    {
        // validation for constraint: string
        if (!is_null($expireDate) && !is_string($expireDate)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($expireDate, true), gettype($expireDate)), __LINE__);
        }
        $this->ExpireDate = $expireDate;
        return $this;
    }
    /**
     * Get ExpireDateExclusiveIndicator value
     * @return bool|null
     */
    public function getExpireDateExclusiveIndicator()
    {
        return $this->ExpireDateExclusiveIndicator;
    }
    /**
     * Set ExpireDateExclusiveIndicator value
     * @param bool $expireDateExclusiveIndicator
     * @return \StructType\InsuranceType
     */
    public function setExpireDateExclusiveIndicator($expireDateExclusiveIndicator = null)
    {
        // validation for constraint: boolean
        if (!is_null($expireDateExclusiveIndicator) && !is_bool($expireDateExclusiveIndicator)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($expireDateExclusiveIndicator, true), gettype($expireDateExclusiveIndicator)), __LINE__);
        }
        $this->ExpireDateExclusiveIndicator = $expireDateExclusiveIndicator;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\InsuranceType
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
