<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for InvBlockCutoff StructType
 * Meta information extracted from the WSDL
 * - documentation: The usage here provides details regarding the inventory count cutoffs. This attribute group was reused and does not apply to blocks, even though the word "block" appears in the attribute group name. | Used for information regarding
 * inventory block cutoff dates.
 * @subpackage Structs
 */
class InvBlockCutoff extends AbstractStructBase
{
    /**
     * The AbsoluteCutoff
     * Meta information extracted from the WSDL
     * - documentation: Defines the absolute deadline. Either this or the offset attributes may be used. | A construct to validate either a date or a time or a dateTime value.
     * - type: DateOrTimeOrDateTimeType
     * - union: date | dateTime | time
     * - use: optional
     * @var string
     */
    public $AbsoluteCutoff;
    /**
     * The OffsetDuration
     * Meta information extracted from the WSDL
     * - documentation: The units of time, e.g.: days, hours, etc., that apply to the deadline.
     * - type: xs:duration
     * - use: optional
     * @var string
     */
    public $OffsetDuration;
    /**
     * The OffsetCalculationMode
     * @var string
     */
    public $OffsetCalculationMode;
    /**
     * Constructor method for InvBlockCutoff
     * @uses InvBlockCutoff::setAbsoluteCutoff()
     * @uses InvBlockCutoff::setOffsetDuration()
     * @uses InvBlockCutoff::setOffsetCalculationMode()
     * @param string $absoluteCutoff
     * @param string $offsetDuration
     * @param string $offsetCalculationMode
     */
    public function __construct($absoluteCutoff = null, $offsetDuration = null, $offsetCalculationMode = null)
    {
        $this
            ->setAbsoluteCutoff($absoluteCutoff)
            ->setOffsetDuration($offsetDuration)
            ->setOffsetCalculationMode($offsetCalculationMode);
    }
    /**
     * Get AbsoluteCutoff value
     * @return string|null
     */
    public function getAbsoluteCutoff()
    {
        return $this->AbsoluteCutoff;
    }
    /**
     * This method is responsible for validating the value passed to the setAbsoluteCutoff method
     * This method is willingly generated in order to preserve the one-line inline validation within the setAbsoluteCutoff method
     * This is a set of validation rules based on the union types associated to the property being set by the setAbsoluteCutoff method
     * @param mixed $value
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateAbsoluteCutoffForUnionConstraintsFromSetAbsoluteCutoff($value)
    {
        $message = '';
        if () {
            $message = sprintf("The value %s does not match any of the union rules: date, dateTime, time. See following errors:\n%s", var_export($value, true), implode("\n", array_map(function(\InvalidArgumentException $e) { return sprintf(' - %s', $e->getMessage()); }, [])));
        }
        unset();
        return $message;
    }
    /**
     * Set AbsoluteCutoff value
     * @param string $absoluteCutoff
     * @return \StructType\InvBlockCutoff
     */
    public function setAbsoluteCutoff($absoluteCutoff = null)
    {
        // validation for constraint: string
        if (!is_null($absoluteCutoff) && !is_string($absoluteCutoff)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($absoluteCutoff, true), gettype($absoluteCutoff)), __LINE__);
        }
        // validation for constraint: union(date, dateTime, time)
        if ('' !== ($absoluteCutoffUnionErrorMessage = self::validateAbsoluteCutoffForUnionConstraintsFromSetAbsoluteCutoff($absoluteCutoff))) {
            throw new \InvalidArgumentException($absoluteCutoffUnionErrorMessage, __LINE__);
        }
        $this->AbsoluteCutoff = $absoluteCutoff;
        return $this;
    }
    /**
     * Get OffsetDuration value
     * @return string|null
     */
    public function getOffsetDuration()
    {
        return $this->OffsetDuration;
    }
    /**
     * Set OffsetDuration value
     * @param string $offsetDuration
     * @return \StructType\InvBlockCutoff
     */
    public function setOffsetDuration($offsetDuration = null)
    {
        // validation for constraint: string
        if (!is_null($offsetDuration) && !is_string($offsetDuration)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($offsetDuration, true), gettype($offsetDuration)), __LINE__);
        }
        $this->OffsetDuration = $offsetDuration;
        return $this;
    }
    /**
     * Get OffsetCalculationMode value
     * @return string|null
     */
    public function getOffsetCalculationMode()
    {
        return $this->OffsetCalculationMode;
    }
    /**
     * Set OffsetCalculationMode value
     * @param string $offsetCalculationMode
     * @return \StructType\InvBlockCutoff
     */
    public function setOffsetCalculationMode($offsetCalculationMode = null)
    {
        // validation for constraint: string
        if (!is_null($offsetCalculationMode) && !is_string($offsetCalculationMode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($offsetCalculationMode, true), gettype($offsetCalculationMode)), __LINE__);
        }
        $this->OffsetCalculationMode = $offsetCalculationMode;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\InvBlockCutoff
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
