<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for LocationCode StructType
 * Meta information extracted from the WSDL
 * - type: StringLength1to16
 * - use: optional
 * @subpackage Structs
 */
class LocationCode extends AbstractStructBase
{
    /**
     * The CityCode
     * Meta information extracted from the WSDL
     * - documentation: Used for Character Strings, length 1 to 8.
     * - base: xs:string
     * - maxLength: 8
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $CityCode;
    /**
     * The StateProvinceCode
     * Meta information extracted from the WSDL
     * - documentation: Used for Character Strings, length 1 to 8.
     * - base: xs:string
     * - maxLength: 8
     * - minLength: 1
     * - use: optional
     * @var string
     */
    public $StateProvinceCode;
    /**
     * The CountryCode
     * Meta information extracted from the WSDL
     * - documentation: Specifies a 2 character country code as defined in ISO3166.
     * - base: xs:string
     * - pattern: [a-zA-Z]{2}
     * - use: optional
     * @var string
     */
    public $CountryCode;
    /**
     * Constructor method for LocationCode
     * @uses LocationCode::setCityCode()
     * @uses LocationCode::setStateProvinceCode()
     * @uses LocationCode::setCountryCode()
     * @param string $cityCode
     * @param string $stateProvinceCode
     * @param string $countryCode
     */
    public function __construct($cityCode = null, $stateProvinceCode = null, $countryCode = null)
    {
        $this
            ->setCityCode($cityCode)
            ->setStateProvinceCode($stateProvinceCode)
            ->setCountryCode($countryCode);
    }
    /**
     * Get CityCode value
     * @return string|null
     */
    public function getCityCode()
    {
        return $this->CityCode;
    }
    /**
     * Set CityCode value
     * @param string $cityCode
     * @return \StructType\LocationCode
     */
    public function setCityCode($cityCode = null)
    {
        // validation for constraint: string
        if (!is_null($cityCode) && !is_string($cityCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($cityCode, true), gettype($cityCode)), __LINE__);
        }
        // validation for constraint: maxLength(8)
        if (!is_null($cityCode) && mb_strlen($cityCode) > 8) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 8', mb_strlen($cityCode)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($cityCode) && mb_strlen($cityCode) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($cityCode)), __LINE__);
        }
        $this->CityCode = $cityCode;
        return $this;
    }
    /**
     * Get StateProvinceCode value
     * @return string|null
     */
    public function getStateProvinceCode()
    {
        return $this->StateProvinceCode;
    }
    /**
     * Set StateProvinceCode value
     * @param string $stateProvinceCode
     * @return \StructType\LocationCode
     */
    public function setStateProvinceCode($stateProvinceCode = null)
    {
        // validation for constraint: string
        if (!is_null($stateProvinceCode) && !is_string($stateProvinceCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($stateProvinceCode, true), gettype($stateProvinceCode)), __LINE__);
        }
        // validation for constraint: maxLength(8)
        if (!is_null($stateProvinceCode) && mb_strlen($stateProvinceCode) > 8) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 8', mb_strlen($stateProvinceCode)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($stateProvinceCode) && mb_strlen($stateProvinceCode) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($stateProvinceCode)), __LINE__);
        }
        $this->StateProvinceCode = $stateProvinceCode;
        return $this;
    }
    /**
     * Get CountryCode value
     * @return string|null
     */
    public function getCountryCode()
    {
        return $this->CountryCode;
    }
    /**
     * Set CountryCode value
     * @param string $countryCode
     * @return \StructType\LocationCode
     */
    public function setCountryCode($countryCode = null)
    {
        // validation for constraint: string
        if (!is_null($countryCode) && !is_string($countryCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($countryCode, true), gettype($countryCode)), __LINE__);
        }
        // validation for constraint: pattern([a-zA-Z]{2})
        if (!is_null($countryCode) && !preg_match('/[a-zA-Z]{2}/', $countryCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [a-zA-Z]{2}', var_export($countryCode, true)), __LINE__);
        }
        $this->CountryCode = $countryCode;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\LocationCode
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
