<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for PrefCollection StructType
 * Meta information extracted from the WSDL
 * - documentation: Allows for control of the sharing of data between parties. | Aggregation of customer travel needs.
 * @subpackage Structs
 */
class PrefCollection extends AbstractStructBase
{
    /**
     * The CommonPref
     * Meta information extracted from the WSDL
     * - documentation: Supplier-independent preferences.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\CommonPrefType[]
     */
    public $CommonPref;
    /**
     * The VehicleRentalPref
     * Meta information extracted from the WSDL
     * - documentation: A set of preferences for vehicle rental.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\VehicleProfileRentalPrefType[]
     */
    public $VehicleRentalPref;
    /**
     * The AirlinePref
     * Meta information extracted from the WSDL
     * - documentation: A set of preferences for air travel.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\AirlinePrefType[]
     */
    public $AirlinePref;
    /**
     * The HotelPref
     * Meta information extracted from the WSDL
     * - documentation: A set of preferences for hotel stay.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\HotelPrefType[]
     */
    public $HotelPref;
    /**
     * The OtherSrvcPref
     * Meta information extracted from the WSDL
     * - documentation: A set of preferences for other services.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\OtherSrvcPrefType[]
     */
    public $OtherSrvcPref;
    /**
     * The TPA_Extensions
     * Meta information extracted from the WSDL
     * - minOccurs: 0
     * - ref: TPA_Extensions
     * @var \StructType\TPA_ExtensionsType
     */
    public $TPA_Extensions;
    /**
     * The TravelPurpose
     * Meta information extracted from the WSDL
     * - documentation: Refer to OpenTravel Code List Travel Purpose (TVP). | Used for codes in the OpenTravel Code tables. Possible values of this pattern are 1, 101, 101.EQP, or 101.EQP.X.
     * - base: xs:string
     * - pattern: [0-9A-Z]{1,3}(\.[A-Z]{3}(\.X){0,1}){0,1}
     * - use: optional
     * @var string
     */
    public $TravelPurpose;
    /**
     * The ShareSynchInd
     * @var string
     */
    public $ShareSynchInd;
    /**
     * The ShareMarketInd
     * @var string
     */
    public $ShareMarketInd;
    /**
     * Constructor method for PrefCollection
     * @uses PrefCollection::setCommonPref()
     * @uses PrefCollection::setVehicleRentalPref()
     * @uses PrefCollection::setAirlinePref()
     * @uses PrefCollection::setHotelPref()
     * @uses PrefCollection::setOtherSrvcPref()
     * @uses PrefCollection::setTPA_Extensions()
     * @uses PrefCollection::setTravelPurpose()
     * @uses PrefCollection::setShareSynchInd()
     * @uses PrefCollection::setShareMarketInd()
     * @param \StructType\CommonPrefType[] $commonPref
     * @param \StructType\VehicleProfileRentalPrefType[] $vehicleRentalPref
     * @param \StructType\AirlinePrefType[] $airlinePref
     * @param \StructType\HotelPrefType[] $hotelPref
     * @param \StructType\OtherSrvcPrefType[] $otherSrvcPref
     * @param \StructType\TPA_ExtensionsType $tPA_Extensions
     * @param string $travelPurpose
     * @param string $shareSynchInd
     * @param string $shareMarketInd
     */
    public function __construct(array $commonPref = array(), array $vehicleRentalPref = array(), array $airlinePref = array(), array $hotelPref = array(), array $otherSrvcPref = array(), \StructType\TPA_ExtensionsType $tPA_Extensions = null, $travelPurpose = null, $shareSynchInd = null, $shareMarketInd = null)
    {
        $this
            ->setCommonPref($commonPref)
            ->setVehicleRentalPref($vehicleRentalPref)
            ->setAirlinePref($airlinePref)
            ->setHotelPref($hotelPref)
            ->setOtherSrvcPref($otherSrvcPref)
            ->setTPA_Extensions($tPA_Extensions)
            ->setTravelPurpose($travelPurpose)
            ->setShareSynchInd($shareSynchInd)
            ->setShareMarketInd($shareMarketInd);
    }
    /**
     * Get CommonPref value
     * @return \StructType\CommonPrefType[]|null
     */
    public function getCommonPref()
    {
        return $this->CommonPref;
    }
    /**
     * This method is responsible for validating the values passed to the setCommonPref method
     * This method is willingly generated in order to preserve the one-line inline validation within the setCommonPref method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateCommonPrefForArrayConstraintsFromSetCommonPref(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $prefCollectionCommonPrefItem) {
            // validation for constraint: itemType
            if (!$prefCollectionCommonPrefItem instanceof \StructType\CommonPrefType) {
                $invalidValues[] = is_object($prefCollectionCommonPrefItem) ? get_class($prefCollectionCommonPrefItem) : sprintf('%s(%s)', gettype($prefCollectionCommonPrefItem), var_export($prefCollectionCommonPrefItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The CommonPref property can only contain items of type \StructType\CommonPrefType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set CommonPref value
     * @throws \InvalidArgumentException
     * @param \StructType\CommonPrefType[] $commonPref
     * @return \StructType\PrefCollection
     */
    public function setCommonPref(array $commonPref = array())
    {
        // validation for constraint: array
        if ('' !== ($commonPrefArrayErrorMessage = self::validateCommonPrefForArrayConstraintsFromSetCommonPref($commonPref))) {
            throw new \InvalidArgumentException($commonPrefArrayErrorMessage, __LINE__);
        }
        $this->CommonPref = $commonPref;
        return $this;
    }
    /**
     * Add item to CommonPref value
     * @throws \InvalidArgumentException
     * @param \StructType\CommonPrefType $item
     * @return \StructType\PrefCollection
     */
    public function addToCommonPref(\StructType\CommonPrefType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\CommonPrefType) {
            throw new \InvalidArgumentException(sprintf('The CommonPref property can only contain items of type \StructType\CommonPrefType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->CommonPref[] = $item;
        return $this;
    }
    /**
     * Get VehicleRentalPref value
     * @return \StructType\VehicleProfileRentalPrefType[]|null
     */
    public function getVehicleRentalPref()
    {
        return $this->VehicleRentalPref;
    }
    /**
     * This method is responsible for validating the values passed to the setVehicleRentalPref method
     * This method is willingly generated in order to preserve the one-line inline validation within the setVehicleRentalPref method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateVehicleRentalPrefForArrayConstraintsFromSetVehicleRentalPref(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $prefCollectionVehicleRentalPrefItem) {
            // validation for constraint: itemType
            if (!$prefCollectionVehicleRentalPrefItem instanceof \StructType\VehicleProfileRentalPrefType) {
                $invalidValues[] = is_object($prefCollectionVehicleRentalPrefItem) ? get_class($prefCollectionVehicleRentalPrefItem) : sprintf('%s(%s)', gettype($prefCollectionVehicleRentalPrefItem), var_export($prefCollectionVehicleRentalPrefItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The VehicleRentalPref property can only contain items of type \StructType\VehicleProfileRentalPrefType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set VehicleRentalPref value
     * @throws \InvalidArgumentException
     * @param \StructType\VehicleProfileRentalPrefType[] $vehicleRentalPref
     * @return \StructType\PrefCollection
     */
    public function setVehicleRentalPref(array $vehicleRentalPref = array())
    {
        // validation for constraint: array
        if ('' !== ($vehicleRentalPrefArrayErrorMessage = self::validateVehicleRentalPrefForArrayConstraintsFromSetVehicleRentalPref($vehicleRentalPref))) {
            throw new \InvalidArgumentException($vehicleRentalPrefArrayErrorMessage, __LINE__);
        }
        $this->VehicleRentalPref = $vehicleRentalPref;
        return $this;
    }
    /**
     * Add item to VehicleRentalPref value
     * @throws \InvalidArgumentException
     * @param \StructType\VehicleProfileRentalPrefType $item
     * @return \StructType\PrefCollection
     */
    public function addToVehicleRentalPref(\StructType\VehicleProfileRentalPrefType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\VehicleProfileRentalPrefType) {
            throw new \InvalidArgumentException(sprintf('The VehicleRentalPref property can only contain items of type \StructType\VehicleProfileRentalPrefType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->VehicleRentalPref[] = $item;
        return $this;
    }
    /**
     * Get AirlinePref value
     * @return \StructType\AirlinePrefType[]|null
     */
    public function getAirlinePref()
    {
        return $this->AirlinePref;
    }
    /**
     * This method is responsible for validating the values passed to the setAirlinePref method
     * This method is willingly generated in order to preserve the one-line inline validation within the setAirlinePref method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateAirlinePrefForArrayConstraintsFromSetAirlinePref(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $prefCollectionAirlinePrefItem) {
            // validation for constraint: itemType
            if (!$prefCollectionAirlinePrefItem instanceof \StructType\AirlinePrefType) {
                $invalidValues[] = is_object($prefCollectionAirlinePrefItem) ? get_class($prefCollectionAirlinePrefItem) : sprintf('%s(%s)', gettype($prefCollectionAirlinePrefItem), var_export($prefCollectionAirlinePrefItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The AirlinePref property can only contain items of type \StructType\AirlinePrefType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set AirlinePref value
     * @throws \InvalidArgumentException
     * @param \StructType\AirlinePrefType[] $airlinePref
     * @return \StructType\PrefCollection
     */
    public function setAirlinePref(array $airlinePref = array())
    {
        // validation for constraint: array
        if ('' !== ($airlinePrefArrayErrorMessage = self::validateAirlinePrefForArrayConstraintsFromSetAirlinePref($airlinePref))) {
            throw new \InvalidArgumentException($airlinePrefArrayErrorMessage, __LINE__);
        }
        $this->AirlinePref = $airlinePref;
        return $this;
    }
    /**
     * Add item to AirlinePref value
     * @throws \InvalidArgumentException
     * @param \StructType\AirlinePrefType $item
     * @return \StructType\PrefCollection
     */
    public function addToAirlinePref(\StructType\AirlinePrefType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\AirlinePrefType) {
            throw new \InvalidArgumentException(sprintf('The AirlinePref property can only contain items of type \StructType\AirlinePrefType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->AirlinePref[] = $item;
        return $this;
    }
    /**
     * Get HotelPref value
     * @return \StructType\HotelPrefType[]|null
     */
    public function getHotelPref()
    {
        return $this->HotelPref;
    }
    /**
     * This method is responsible for validating the values passed to the setHotelPref method
     * This method is willingly generated in order to preserve the one-line inline validation within the setHotelPref method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateHotelPrefForArrayConstraintsFromSetHotelPref(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $prefCollectionHotelPrefItem) {
            // validation for constraint: itemType
            if (!$prefCollectionHotelPrefItem instanceof \StructType\HotelPrefType) {
                $invalidValues[] = is_object($prefCollectionHotelPrefItem) ? get_class($prefCollectionHotelPrefItem) : sprintf('%s(%s)', gettype($prefCollectionHotelPrefItem), var_export($prefCollectionHotelPrefItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The HotelPref property can only contain items of type \StructType\HotelPrefType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set HotelPref value
     * @throws \InvalidArgumentException
     * @param \StructType\HotelPrefType[] $hotelPref
     * @return \StructType\PrefCollection
     */
    public function setHotelPref(array $hotelPref = array())
    {
        // validation for constraint: array
        if ('' !== ($hotelPrefArrayErrorMessage = self::validateHotelPrefForArrayConstraintsFromSetHotelPref($hotelPref))) {
            throw new \InvalidArgumentException($hotelPrefArrayErrorMessage, __LINE__);
        }
        $this->HotelPref = $hotelPref;
        return $this;
    }
    /**
     * Add item to HotelPref value
     * @throws \InvalidArgumentException
     * @param \StructType\HotelPrefType $item
     * @return \StructType\PrefCollection
     */
    public function addToHotelPref(\StructType\HotelPrefType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\HotelPrefType) {
            throw new \InvalidArgumentException(sprintf('The HotelPref property can only contain items of type \StructType\HotelPrefType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->HotelPref[] = $item;
        return $this;
    }
    /**
     * Get OtherSrvcPref value
     * @return \StructType\OtherSrvcPrefType[]|null
     */
    public function getOtherSrvcPref()
    {
        return $this->OtherSrvcPref;
    }
    /**
     * This method is responsible for validating the values passed to the setOtherSrvcPref method
     * This method is willingly generated in order to preserve the one-line inline validation within the setOtherSrvcPref method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateOtherSrvcPrefForArrayConstraintsFromSetOtherSrvcPref(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $prefCollectionOtherSrvcPrefItem) {
            // validation for constraint: itemType
            if (!$prefCollectionOtherSrvcPrefItem instanceof \StructType\OtherSrvcPrefType) {
                $invalidValues[] = is_object($prefCollectionOtherSrvcPrefItem) ? get_class($prefCollectionOtherSrvcPrefItem) : sprintf('%s(%s)', gettype($prefCollectionOtherSrvcPrefItem), var_export($prefCollectionOtherSrvcPrefItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The OtherSrvcPref property can only contain items of type \StructType\OtherSrvcPrefType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set OtherSrvcPref value
     * @throws \InvalidArgumentException
     * @param \StructType\OtherSrvcPrefType[] $otherSrvcPref
     * @return \StructType\PrefCollection
     */
    public function setOtherSrvcPref(array $otherSrvcPref = array())
    {
        // validation for constraint: array
        if ('' !== ($otherSrvcPrefArrayErrorMessage = self::validateOtherSrvcPrefForArrayConstraintsFromSetOtherSrvcPref($otherSrvcPref))) {
            throw new \InvalidArgumentException($otherSrvcPrefArrayErrorMessage, __LINE__);
        }
        $this->OtherSrvcPref = $otherSrvcPref;
        return $this;
    }
    /**
     * Add item to OtherSrvcPref value
     * @throws \InvalidArgumentException
     * @param \StructType\OtherSrvcPrefType $item
     * @return \StructType\PrefCollection
     */
    public function addToOtherSrvcPref(\StructType\OtherSrvcPrefType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\OtherSrvcPrefType) {
            throw new \InvalidArgumentException(sprintf('The OtherSrvcPref property can only contain items of type \StructType\OtherSrvcPrefType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->OtherSrvcPref[] = $item;
        return $this;
    }
    /**
     * Get TPA_Extensions value
     * @return \StructType\TPA_ExtensionsType|null
     */
    public function getTPA_Extensions()
    {
        return $this->TPA_Extensions;
    }
    /**
     * Set TPA_Extensions value
     * @param \StructType\TPA_ExtensionsType $tPA_Extensions
     * @return \StructType\PrefCollection
     */
    public function setTPA_Extensions(\StructType\TPA_ExtensionsType $tPA_Extensions = null)
    {
        $this->TPA_Extensions = $tPA_Extensions;
        return $this;
    }
    /**
     * Get TravelPurpose value
     * @return string|null
     */
    public function getTravelPurpose()
    {
        return $this->TravelPurpose;
    }
    /**
     * Set TravelPurpose value
     * @param string $travelPurpose
     * @return \StructType\PrefCollection
     */
    public function setTravelPurpose($travelPurpose = null)
    {
        // validation for constraint: string
        if (!is_null($travelPurpose) && !is_string($travelPurpose)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($travelPurpose, true), gettype($travelPurpose)), __LINE__);
        }
        // validation for constraint: pattern([0-9A-Z]{1,3}(\.[A-Z]{3}(\.X){0,1}){0,1})
        if (!is_null($travelPurpose) && !preg_match('/[0-9A-Z]{1,3}(\\.[A-Z]{3}(\\.X){0,1}){0,1}/', $travelPurpose)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [0-9A-Z]{1,3}(\.[A-Z]{3}(\.X){0,1}){0,1}', var_export($travelPurpose, true)), __LINE__);
        }
        $this->TravelPurpose = $travelPurpose;
        return $this;
    }
    /**
     * Get ShareSynchInd value
     * @return string|null
     */
    public function getShareSynchInd()
    {
        return $this->ShareSynchInd;
    }
    /**
     * Set ShareSynchInd value
     * @param string $shareSynchInd
     * @return \StructType\PrefCollection
     */
    public function setShareSynchInd($shareSynchInd = null)
    {
        // validation for constraint: string
        if (!is_null($shareSynchInd) && !is_string($shareSynchInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shareSynchInd, true), gettype($shareSynchInd)), __LINE__);
        }
        $this->ShareSynchInd = $shareSynchInd;
        return $this;
    }
    /**
     * Get ShareMarketInd value
     * @return string|null
     */
    public function getShareMarketInd()
    {
        return $this->ShareMarketInd;
    }
    /**
     * Set ShareMarketInd value
     * @param string $shareMarketInd
     * @return \StructType\PrefCollection
     */
    public function setShareMarketInd($shareMarketInd = null)
    {
        // validation for constraint: string
        if (!is_null($shareMarketInd) && !is_string($shareMarketInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shareMarketInd, true), gettype($shareMarketInd)), __LINE__);
        }
        $this->ShareMarketInd = $shareMarketInd;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\PrefCollection
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
